@@ -42,6 +42,9 @@
 #include "Misc.h"
 #include "OverrideCursor.h"
 #include "Settings.h"
+#ifndef gmic_core
+#include "CImg.h"
+#endif
 #include "gmic.h"
 
 namespace GmicQt
